# Language-Country Negotiation

The Language-Country Negotiation module aims to provide language negotiation functionality in Drupal while also handling the current country of the visitor via a language-country path prefix.

## What does this module do?

With the Language-Country Negotiation module, users can navigate your site using URLs like:

> `example.com/{$LANGCODE}-{$COUNTRY_CODE}`.

This approach informs the language manager of the current language and the current country service of the visitor's country code. For example:

- example.com/de-de (German in Germany)
- example.com/en-gb (English in Great Britian)
- example.com/en-kr (English in South Korea)

Additionally, users can access the site without a path prefix, entering an international state. In this mode, other negotiation methods such as URL (Path prefix) can come into play. This feature is particularly useful when implementing a country banner or allowing users to browse the website without specifying a country.

## How to use?

Warning: At the moment, this module uses a country taxonomy with the machine name country. This may collide with a pre-configured taxonomy.

1. **Installation:** Start by installing the module via Composer.
2. **Add Countries:** Go to _Structure > Taxonomy > Country_ and add the desired countries as terms.
3. **Activation:** Go to _Configuration > Region and language > Languages > Detection_ and selection and activate the Language-Country URL detection method.
4. **Configuration (Planned):** Customize the detection method with prefix patterns and language codes. Optionally, enable negotiation for admin pages and strict negotiation (disallowing the international state).
5. **Fallbacks:** Navigate to _Configuration > Region and language > Languages > Language-country fallbacks_ to activate convenient fallback methods for the path prefix and the path alias manager.

## Features

This module provides a lightweight implementation of a language negotiation plugin, with the following objectives:

1. **Current Country Service:** Offer a streamlined `CurrentCountry` service that can be consumed by downstream logic, enabling easy retrieval of the current country code. Use as follows: `$this->currentCountry->getCurrentCountryCode();`
2. **Flexible Country Entities (Planned):** Allow easy extension of country entities because they are fieldable, and all configuration for language-country combinations is managed here.
3. **Configurable Language Per Country:** Make it possible to configure allowed languages per country, offering flexibility in content delivery.
4. **Enhanced Path Processing:** Improve the end-user experience with adaptable path processing. The module includes a fallback path alias manager.
5. **Integration (Planned):** Integrate with custom translation fallback chains for different countries based on the _Entity Language Fallback_ module.

## Development Plan

Please note that this module is still in development, and several planned enhancements are in the pipeline before reaching a stable release. These include:

1. Custom Entity for Countries: Implement a custom entity structure for representing countries.
2. Country Switcher Block: Improve the country switcher block and its corresponding template.
3. Plugin Configuration: Allow configuration options for the prefix pattern, exclusion of admin pages from negotiation, and enabling strict negotiation (disallowing the international state).
4. Sub-Modules: Create sub-modules to manage different fallback mechanisms.
5. Integration: Connect with the Entity Language Fallback module.
6. Access Policy Sub-Module: Provide a sub-module with access policy features.

## Similar projects

For similar functionality, you may explore the _Domain_ module ecosystem. Additionally, you can achieve similar behavior with the _Domain Country Path_ module.

## Sponsored by Factorial GmbH

This project is sponsored by [Factorial GmbH](https://www.factorial.io). Drop us a line if you are looking for interesting open source employment.

## Maintainer

- Simon Bäse
- Anna Demianik
